vcf2clinvar
===

Generate a report based on matching a genome VCF to the VCF version of ClinVar's variant database.

This code is intended to be used as a module (installable via pip), for use in other systems or pipelines.

